coef.qmix: Extract coefficients from a qmix object
Description
Create a table of coefficient results from a qmix object.
Usage
# S3 method for qmix
coef(object, ...)
Arguments
object
A qmix object from running the main function qmix.
...
Further arguments to be passed according to coef.
Value
A table of coefficients with their corresponding lower and upper bounds.