print.qmix: Print returns from a qmix object
Description
General print function for qmix objects, which dispatches the chosen type
of printing to the corresponding function.
Usage
# S3 method for qmix
print(x, type = "text", ...)
Arguments
x
A qmix object to be printed.
type
Character string giving the type of printing, such as
"text", "mcmc", "coef".
...
Additional arguments to be passed to print functions (check the See Also section).