print_mcmc.qmix: Print convergence diagnostics from a qmix object
Description
print_mcmc.qmix prints a number of diagnostics about the convergence of a qmix objects.
Usage
print_mcmc.qmix(object, ...)
Arguments
...
Additional arguments to be passed to the print function.